@@ -32,8 +32,8 @@ for cpus in 1 2 ; do
 
   echo IM_CONCURRENCY=$IM_CONCURRENCY
   echo time -p vips im_benchmarkn temp.v temp2.v $chain
-  time vips im_benchmarkn temp.v temp2.v $chain
-  time vips im_benchmarkn temp.v temp2.v $chain
+  time -p vips im_benchmarkn temp.v temp2.v $chain
+  time -p vips im_benchmarkn temp.v temp2.v $chain
 
   if [ $? != 0 ]; then
     echo "benchmark failed -- install problem?"
