@@ -7,11 +7,14 @@ rm -f Makefile Makefile.in aclocal.m4
 rm -rf autom4te.cache
 rm -f config.* configure depcomp
 rm -f install-sh intltool-* libtool ltmain.sh missing mkinstalldirs
-rm -f stamp-* vipsCC-7.14.pc vips-7.14.spec vips-7.14.pc
-rm -f python/vipsCC/*.cxx
-rm -f python/vipsCC/VImage.h
-rm -f python/vipsCC/VImage.py python/vipsCC/VError.py python/vipsCC/VMask.py python/vipsCC/Display.py
+rm -f stamp-* vipsCC-7.19.pc vips-7.19.spec vips-7.19.pc
+rm -f swig/vipsCC/*.cxx
+rm -f swig/vipsCC/VImage.h
+rm -f swig/vipsCC/VImage.py python/vipsCC/VError.py python/vipsCC/VMask.py python/vipsCC/Display.py
 rm -f benchmark/temp*
+( cd doc ; mkdir poop ; mv reference/libvips-docs.sgml.in poop ; mv reference/Makefile.am poop ; mv reference/images poop ; rm -rf reference/* ; mv poop/* reference ; rmdir poop )
+
+gtkdocize --copy --docdir doc/reference --flavour no-tmpl || exit 1
 
 # some systems need libtoolize, some glibtoolize ... how annoying
 echo testing for glibtoolize ...
@@ -33,3 +36,7 @@ autoheader
 $LIBTOOLIZE --copy --force --automake
 automake --add-missing --copy
 
+swig -version > /dev/null
+if [ $? -ne 0 ]; then
+  echo you need swig to build from SVN
+fi
