@@ -43,8 +43,11 @@ extern "C" {
 
 /* Private to iofuncs: the image size above which we switch from
  * mmap()-whole-image behaviour to mmap()-window, plus window margins.
+ *
+ * Always use mmap windows, they put a lot less strain on the VM system when
+ * we have many open images.
  */
-#define IM__MMAP_LIMIT (1024*1024*30)
+#define IM__MMAP_LIMIT (0)
 #define IM__WINDOW_MARGIN (128)
 
 /* sizeof() a VIPS header on disc.
